#include <pi-contact.h>
#include "../jpilot_src/libplugin.h"
#include "pytype_basics.h"

extern PyObject* PyPiContact_New();
extern PyObject* PyPiContact_Wrap(struct Contact*, PCRecType, unsigned int, unsigned char,
				 int, void*, PyObject *);

extern PyTypeObject ContactType;

#define PyPiContact_Check(v)          PyObject_TypeCheck(v, &ContactType)
#define PyPiContact_CheckExact(v)     ((v)->ob_type == &ContactType)

typedef struct {
  PyObject_HEAD
  PyObject_JPTYPE
  struct Contact a;
} PyPiContact;
